@@ -11,28 +11,28 @@
 #'
 #'
 #'
-#' @return list consisting of a non-numeric decision whether to reject the null hypothesis or not, the significance level, the number of bootstrap samples used, and the bootstrap P-value  calculated using the Euclidean distance.  
+#' @return list consisting of a non-numeric decision whether to reject the null hypothesis or not, the significance level, and the number of bootstrap samples used 
 #'
 #'
 #'
 #' @references
 #'
 #' Cahoy, DO (2010), \emph{A Bootstrap Test For Equality Of Variances,} Computational Statistics & Data Analysis, 54(10), 2306-2316.
-#' <doi:10.1016/j.csda.2010.04.012>
+#' \doi{10.1016/j.csda.2010.04.012}
 #'
 #'
 #'
 #' @examples
 #'
 #'
-#' x1=sqrt(10)*runif(8, -sqrt(3), sqrt(3) )
-#' x2=sqrt(1)*runif(8, -sqrt(3), sqrt(3) )
-#' equa2vartest(x1,x2,0.05, 1000)
+#' x1=sqrt(10)*runif(7, -sqrt(3), sqrt(3) )
+#' x2=sqrt(1)*runif(7, -sqrt(3), sqrt(3) )
+#' equa2vartest(x1,x2,0.05, 500)
 #'
 #'
 #'
-#' x1=sqrt(1)*rexp(8)
-#' x2=sqrt(1)*rexp(8)
+#' x1=sqrt(1)*rexp(7)
+#' x2=sqrt(1)*rexp(7)
 #' equa2vartest(x1,x2,0.01, 1000)
 #'
 #'
@@ -82,14 +82,11 @@ equa2vartest=function(x1, x2, a, B){
   y<-y22[complete.cases(y22),]
   y<-(y[,1:(k+1)])/y[, ((k+1)+1):(2*(k+1))]
   avey<-colMeans(y)
-  ycntr<-(y-matrix(rep(avey,length(y[,1])), nrow=length(y[,1]), byrow=T) )
-  y<-ycntr[,1]
+  y<-(y-matrix(rep(avey,length(y[,1])), nrow=length(y[,1]), byrow=T) )[,1]
   y<- y[abs(y)<Inf]
   B2<-length(y)
   cval<- sort( abs(y), decreasing=T)[ceiling(B2*a) + 1]
   ts2<- c( (yy1/sqrt(vary1c)),(yy2/sqrt(vary2c)) )
   ind <- ifelse( sum( ifelse( ( abs(ts2) > rep( cval ,(k+1) ) ), 1, 0) ) >0,1,0 )
-  dum=ifelse( (abs(ycntr)>abs(ts2))==c("TRUE", "TRUE"), 1,0)
-  pval<-round((sum(apply(dum,1,sum)==2)+1)/B2,3)
-  return(list(ifelse(ind==0,"Decision: Fail to Reject the Null", "Decision: Reject the Null"), Alpha=a, NumberOfBootSamples=B, BootPvalue=pval ) )
+  return(list(ifelse(ind==0,"Decision: Fail to Reject the Null", "Decision: Reject the Null"), Alpha=a, NumberOfBootSamples=B ) )
 }
